# spey-pyhf

``pyhf`` plugin for spey interface. This plug-in can be installed via

```bash
pip install spey-pyhf
```

command. Once installed ``spey`` interface will be able to automatically detect it.
For details on usage please see the online documentation.
